"use strict";
/*
  This program and the accompanying materials are
  made available under the terms of the Eclipse Public License v2.0 which accompanies
  this distribution, and is available at https://www.eclipse.org/legal/epl-v20.html

  SPDX-License-Identifier: EPL-2.0

  Copyright Contributors to the Zowe Project.
*/
exports.__esModule = true;
var express = require("express");
var StorageDataService = /** @class */ (function () {
    function StorageDataService(context) {
        this.context = context;
        var storage = this.context.storage;
        var router = express.Router();
        this.router = router;
        context.addBodyParseMiddleware(router);
        router.post('/', function (req, res) {
            var storageType = req.query.storageType;
            var dict = req.body;
            storage.setAll(dict, storageType).then(function () {
                res.sendStatus(204);
            })["catch"](function (e) {
                res.status(500).json({
                    err: e.message
                });
            });
        });
        router.get('/', function (req, res) {
            var storageType = req.query.storageType;
            storage.getAll(storageType).then(function (dict) {
                res.status(200).json(dict);
            })["catch"](function (e) {
                res.status(500).json({
                    err: e.message
                });
            });
        });
        router["delete"]('/', function (req, res) {
            var storageType = req.query.storageType;
            storage.deleteAll(storageType).then(function () {
                res.sendStatus(204);
            })["catch"](function (e) {
                res.status(500).json({
                    err: e.message
                });
            });
        });
        router.post('/:key', function (req, res) {
            var key = req.params.key;
            var storageType = req.query.storageType;
            var value = req.body.value;
            storage.set(key, value, storageType).then(function () {
                res.sendStatus(204);
            })["catch"](function (e) {
                res.status(500).json({
                    err: e.message
                });
            });
        });
        router.get('/:key', function (req, res) {
            var key = req.params.key;
            var storageType = req.query.storageType;
            storage.get(key, storageType).then(function (value) {
                res.status(200).json({ key: key, value: value });
            })["catch"](function (e) {
                res.status(500).json({
                    err: e.message
                });
            });
        });
        router["delete"]('/:key', function (req, res) {
            var key = req.params.key;
            var storageType = req.query.storageType;
            storage["delete"](key, storageType).then(function () {
                res.sendStatus(204);
            })["catch"](function (e) {
                res.status(500).json({
                    err: e.message
                });
            });
        });
    }
    StorageDataService.prototype.getRouter = function () {
        return this.router;
    };
    return StorageDataService;
}());
function storageRouter(context) {
    var dataService = new StorageDataService(context);
    return Promise.resolve(dataService.getRouter());
}
exports.storageRouter = storageRouter;
/*
  This program and the accompanying materials are
  made available under the terms of the Eclipse Public License v2.0 which accompanies
  this distribution, and is available at https://www.eclipse.org/legal/epl-v20.html

  SPDX-License-Identifier: EPL-2.0

  Copyright Contributors to the Zowe Project.
*/
//# sourceMappingURL=storage.js.map